caellion-python-commons: caellion.pycommons.encoding.base36.InvalidInputStringException Class Reference

caellion-python-commons

caellion.pycommons.encoding.base36.InvalidInputStringException Class Reference

This exception is raised when encountering a character not defined in custom charset in input string. More...

Inheritance diagram for caellion.pycommons.encoding.base36.InvalidInputStringException:

## Detailed Description

This exception is raised when encountering a character not defined in custom charset in input string.

Definition at line 22 of file base36.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/encoding/base36.py